@@ -13,7 +13,7 @@ from flask_migrate import Migrate
 from cryptography.hazmat.primitives.hashes import SHA256
 from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
 
-from .database import db, User
+from .database import db, AnonymousUser, User
 from .views.authentication import authentication
 from .views.home import home
 from .views.projects import projects
@@ -79,6 +79,7 @@ kdf = PBKDF2HMAC(
 app.encryption_key = base64.urlsafe_b64encode(kdf.derive(app.secret_key.encode()))
 
 login_manager = LoginManager()
+login_manager.anonymous_user = AnonymousUser
 login_manager.login_view = "authentication.login"
 login_manager.init_app(app)
 
@@ -90,7 +91,10 @@ def load_user(user_id):
     return User.query.get(user_id)
 
 def cactool():
-    subprocess.call([STARTUP_SCRIPT_LOCATION, *sys.argv[1:]], shell=True) 
+    try:
+        subprocess.call([STARTUP_SCRIPT_LOCATION, *sys.argv[1:]], shell=True)
+    except KeyboardInterrupt:
+        pass
 
 if __name__ == "__main__":
     app = create_app()
